SoloPoolMiner.exetigerrat analysis report - Suspicious
Run integrity
sample ranThe guest staged the sample and launched it, so what follows describes this file rather than an empty desktop.
Suspicious
35/100
0 points past the suspicious line at 35, 35 short of malicious at 70.
Why this verdict
- Identified as Tiger RAT (possible confidence, named by static_yara)
Model reading
Evidence ledger above, row by row. Published verdict rests on this column and on nothing to its right.
Reads this report's derived findings, never the sample itself.
A model reading exists for this scan and is shown to the submitter and to staff only. It is a second opinion about evidence the score already priced, it is worth no points, and on a public page it would stand beside the verdict with no grounding a stranger could check.
Analysis layers
Malware family
1 independent sourceNamed by a single source. Treat it as a lead rather than a classification.
| Layer | Source | What it matched |
|---|---|---|
| static_yara | rule corpus | TigerRAT_pe_yaraify |
Detection signatures
7 detected · 9 withheld as common| Severity | Detection | Evidence | Layer |
|---|---|---|---|
| MED |
Anti-analysis strings present
MITRE T1497
|
string
isdebuggerpresent
matched string
|
static |
| MED |
Ransomware-related strings
MITRE T1486
|
string
bitcoin
matched string
|
static |
| MED |
Raw socket networking
MITRE T1095
|
import
ws2_32.dll!WSAStartup
|
static |
| MED |
TLS callback (pre-main execution)
MITRE T1055
|
pe_header
IMAGE_DIRECTORY_ENTRY_TLS present
callbacks run before the entry point
|
static |
| LOW |
Executes via ShellExecute
MITRE T1204
seen in 12% of benign software
|
import
shell32.dll!ShellExecuteA
|
static |
| LOW |
Hides its window (ShowWindow SW_HIDE pattern)
MITRE T1564.003
seen in 13% of benign software
|
import
user32.dll!ShowWindow
|
static |
| LOW |
Network communication capability
MITRE T1071
seen in 6% of benign software
|
capability
connect
capability: network
capability
recv
capability: network
capability
send
capability: network
capability
socket
capability: network
capability
wsastartup
capability: network
|
static |
These rules matched this sample, and they also match this much of known-clean software (measured over 1145 signed Windows and third-party binaries). A rule that fires on most clean files cannot move a verdict, so it is held back unless the detonation confirms the behaviour. They are listed because a count that shrinks without saying so is not a count an analyst can check.
What the tests returned
8 testsEach test this run performed and what it returned. A test that was not performed says so rather than reading as a negative result.
| Test | Result |
|---|---|
| Persistence mechanisms | none established at runtime |
| Cross-process injection | none observed |
| Payloads written to disk | none observed |
| Network connections | not tested - internet was disabled |
| Behavioural rule matches (Sigma) | none observed |
| Known-malicious hash (reputation sources) | no source reported this file |
| Local anti-virus engine | reported no detection |
| Anti-analysis / evasion checks | not measured on this run - no in-process API monitor reported in, so the runtime anti-debug and anti-VM calls were never watched |
Absence of an observation is not proof of absence - see Coverage for what this run could and could not test.
Arguing against malice
- The local anti-virus engine reported no detection.
- No reputation source reported this file as malicious.
How much weight this carries
Structure only. Structural evidence only. Nothing matching this verdict was seen running. The one fact that decided it: capability analysis of the file's imports.
Structure
What the file is made of: headers, imports, how it was built and whether it was signed.
Sections & resources
How the file is laid out in memory, and what is embedded in it: section roles, access rights, entropy and every resource entry.
Signatures & packing
What matched and what is hidden: signature rules, detected capabilities, family attribution, packer detection, unpacked payloads and recovered configuration.
Strings
The readable content: embedded secrets, flagged strings and everything extraction recovered.
Code
What the sample would execute: the emulated API call sequence, and the disassembled entry point.
Antivirus engine
no signature matchedNothing in the signature set below matched this file. That is one engine's negative answer against one signature set on one day, and it is not a verdict. A signature engine only recognises what has already been named and published, so a file nobody has named yet scans exactly like a file that is harmless. What this file does when it runs is the stronger evidence; read the behaviour sections for that.
This run did not record which signature set answered, so the result above cannot be tied to a named set or reproduced against one. Recording the set began part way through this platform's history, and this scan predates it.
Local ML assessment
no model scoreThis scan ran before the local classifier was installed on this host, so no model score was produced for it. Submitting the same file again produces one.
Structural rules of thumb, not a model. 2 cheap static signals fired, for 15 of 100 on a rule-of-thumb scale that is deliberately left out of the verdict score: the packing, entropy and signing cards on this report already price the same facts, and counting them a second time under a machine-learning heading would charge one piece of evidence twice.
- unsigned executable
- TLS callback
- Non-standard section names: .nv_fatb, .nvFatBi, .fptable
- TLS callback present
Secrets & malicious strings
2 flagged stringsFlagged string categories
| Indicator | Found in | Evidence from the sample |
|---|---|---|
| isdebuggerpresent | import table | KERNEL32.dll!IsDebuggerPresent |
| Indicator | Found in | Evidence from the sample |
|---|---|---|
| bitcoin | extracted string | Please enter a valid Bitcoin address |
Capabilities
7 behaviour buckets · 1 high-risk| Severity | Capability | MITRE | APIs |
|---|---|---|---|
| high | Anti-debugging Detects or obstructs a debugger |
T1622 | isdebuggerpresent |
| med | Network / C2 Opens sockets, HTTP or downloads payloads |
T1071, T1095 | connect, recv, send, socket, wsastartup |
| med | Evasion / stalling Sleeps, times, or otherwise stalls analysis |
T1497, T1497.003 | getsystemtimeasfiletime, gettickcount, queryperformancecounter, sleep |
| med | Code execution Creates processes / runs commands or shellcode |
T1106, T1203 | createthread, shellexecutea |
| med | Dynamic API resolution Resolves APIs at runtime (obfuscation) |
T1129 | getprocaddress, loadlibraryexa |
| med | Ransomware behaviour Enumerates + encrypts files, deletes backups |
T1083 | findnextfilew |
| low | Discovery Enumerates the host, users, processes or network |
T1082 | getsysteminfo |
Security mitigations
partial postureRich header (toolchain)
richhash 45d3a3ed2a129df6| Tool | Build | Uses |
|---|---|---|
| Export 14.10 | 33145 | 160 |
| Cvtres 14.10 | 33145 | 88 |
| Utc1900 (VS2017) | 33145 | 27 |
| Utc1900 (VS2017) | 35403 | 9 |
| Cvtres 14.10 | 35403 | 17 |
| Export 14.10 | 35403 | 41 |
| Cvtres 14.10 | 29913 | 12 |
| Utc1900 (VS2017) | 29111 | 2 |
| Utc1900 (VS2017) | 29913 | 2 |
| Import (linker) | 0 | 179 |
| Utc1900 (VS2017) | 33145 | 13 |
| Export 14.10 | 35722 | 2 |
| AliasObj 14.10 | 35722 | 1 |
Sections
8 sections · the file's memory layout| Section | Virtual addr | Raw size | Virtual size | Access | Entropy |
|---|---|---|---|---|---|
|
.textEP
Executable code
|
0x1000 |
169.5 KB
|
169.4 KB
|
EXECUTEREAD
|
6.525
|
|
.rdata
Read-only data
|
0x2c000 |
65.5 KB
|
65.1 KB
|
READ
|
5.5892
|
|
.data
Initialised data
|
0x3d000 |
3.0 KB
|
60.5 KB
expands
|
READWRITE
|
2.0603
|
|
.pdata
Exception unwind data
|
0x4d000 |
7.5 KB
|
7.2 KB
|
READ
|
5.3215
|
|
.nv_fatb
Non-standard section
|
0x4f000 |
163.5 KB
|
163.4 KB
|
READ
|
5.485
|
|
.nvFatBi
Non-standard section
|
0x78000 |
512.0 B
|
48.0 B
|
READ
|
0.4271
|
|
.fptable
Non-standard section
|
0x79000 |
512.0 B
|
256.0 B
|
READWRITE
|
0.0
|
|
.reloc
Base relocations
|
0x7a000 |
2.0 KB
|
1.7 KB
|
READ
|
5.022
|
Imports
161 funcs / 8 DLLs · 11 suspicious| Name | File RVA | Is undocumented | MITRE (tactic - technique) |
|---|---|---|---|
| connect | 0x0002c4c0 | - | T1071 |
| recv | 0x0002c4c8 | - | - |
| select | 0x0002c4d0 | - | - |
| send | 0x0002c4d8 | - | T1071 |
| setsockopt | 0x0002c4e0 | - | - |
| socket | 0x0002c4e8 | - | T1071 |
| freeaddrinfo | 0x0002c4f0 | - | - |
| getaddrinfo | 0x0002c4f8 | - | - |
| WSACleanup | 0x0002c500 | - | - |
| WSAStartup | 0x0002c508 | - | T1071 |
| closesocket | 0x0002c510 | - | - |
| Name | File RVA | Is undocumented | MITRE (tactic - technique) |
|---|---|---|---|
| ordinal_17 | 0x0002c000 | yes | - |
| Name | File RVA | Is undocumented | MITRE (tactic - technique) |
|---|---|---|---|
| MoveToEx | 0x0002c010 | - | - |
| SetTextColor | 0x0002c018 | - | - |
| SetBkMode | 0x0002c020 | - | - |
| SelectObject | 0x0002c028 | - | - |
| TextOutA | 0x0002c030 | - | - |
| LineTo | 0x0002c038 | - | - |
| DeleteObject | 0x0002c040 | - | - |
| CreateSolidBrush | 0x0002c048 | - | - |
| CreatePen | 0x0002c050 | - | - |
| CreateFontA | 0x0002c058 | - | - |
| Rectangle | 0x0002c060 | - | - |
| Name | File RVA | Is undocumented | MITRE (tactic - technique) |
|---|---|---|---|
| SendMessageA | 0x0002c400 | - | - |
| DefWindowProcA | 0x0002c408 | - | - |
| DispatchMessageA | 0x0002c410 | - | - |
| TranslateMessage | 0x0002c418 | - | - |
| GetMessageA | 0x0002c420 | - | - |
| PostQuitMessage | 0x0002c428 | - | - |
| LoadIconA | 0x0002c430 | - | - |
| LoadCursorA | 0x0002c438 | - | - |
| FillRect | 0x0002c440 | - | - |
| MessageBoxA | 0x0002c448 | - | - |
| GetWindowTextLengthA | 0x0002c450 | - | - |
| GetWindowTextA | 0x0002c458 | - | - |
| SetWindowTextA | 0x0002c460 | - | - |
| InvalidateRect | 0x0002c468 | - | - |
| UpdateWindow | 0x0002c470 | - | - |
| EnableWindow | 0x0002c478 | - | - |
| KillTimer | 0x0002c480 | - | - |
| SetTimer | 0x0002c488 | - | - |
| ShowWindow | 0x0002c490 | - | - |
| DestroyWindow | 0x0002c498 | - | - |
| IsWindow | 0x0002c4a0 | - | - |
| CreateWindowExA | 0x0002c4a8 | - | - |
| RegisterClassExA | 0x0002c4b0 | - | - |
| Name | File RVA | Is undocumented | MITRE (tactic - technique) |
|---|---|---|---|
| ShellExecuteA | 0x0002c3f0 | - | T1106 |
| Name | File RVA | Is undocumented | MITRE (tactic - technique) |
|---|---|---|---|
| nvmlDeviceGetHandleByIndex_v2 | 0x0002c520 | - | - |
| nvmlShutdown | 0x0002c528 | - | - |
| nvmlInit_v2 | 0x0002c530 | - | - |
| nvmlDeviceGetUtilizationRates | 0x0002c538 | - | - |
| Name | File RVA | Is undocumented | MITRE (tactic - technique) |
|---|---|---|---|
| clGetPlatformIDs | 0x0002c338 | - | - |
| clCreateCommandQueue | 0x0002c340 | - | - |
| clEnqueueNDRangeKernel | 0x0002c348 | - | - |
| clEnqueueFillBuffer | 0x0002c350 | - | - |
| clEnqueueWriteBuffer | 0x0002c358 | - | - |
| clEnqueueReadBuffer | 0x0002c360 | - | - |
| clFinish | 0x0002c368 | - | - |
| clSetKernelArg | 0x0002c370 | - | - |
| clReleaseKernel | 0x0002c378 | - | - |
| clCreateKernel | 0x0002c380 | - | - |
| clGetProgramBuildInfo | 0x0002c388 | - | - |
| clBuildProgram | 0x0002c390 | - | - |
| clReleaseProgram | 0x0002c398 | - | - |
| clCreateProgramWithSource | 0x0002c3a0 | - | - |
| clReleaseMemObject | 0x0002c3a8 | - | - |
| clCreateBuffer | 0x0002c3b0 | - | - |
| clReleaseCommandQueue | 0x0002c3b8 | - | - |
| clReleaseContext | 0x0002c3c0 | - | - |
| clCreateContext | 0x0002c3c8 | - | - |
| clGetDeviceInfo | 0x0002c3d0 | - | - |
| clGetDeviceIDs | 0x0002c3d8 | - | - |
| clGetPlatformInfo | 0x0002c3e0 | - | - |
| Name | File RVA | Is undocumented | MITRE (tactic - technique) |
|---|---|---|---|
| SetStdHandle | 0x0002c070 | - | - |
| GetStringTypeW | 0x0002c078 | - | - |
| SetFilePointerEx | 0x0002c080 | - | - |
| ReadFile | 0x0002c088 | - | - |
| ReadConsoleW | 0x0002c090 | - | - |
| CreateFileW | 0x0002c098 | - | - |
| GetFileSizeEx | 0x0002c0a0 | - | - |
| HeapSize | 0x0002c0a8 | - | - |
| WriteConsoleW | 0x0002c0b0 | - | - |
| SetEndOfFile | 0x0002c0b8 | - | - |
| InitOnceExecuteOnce | 0x0002c0c0 | - | - |
| GetProcessHeap | 0x0002c0c8 | - | - |
| FreeEnvironmentStringsW | 0x0002c0d0 | - | - |
| GetEnvironmentStringsW | 0x0002c0d8 | - | - |
| WideCharToMultiByte | 0x0002c0e0 | - | - |
| MultiByteToWideChar | 0x0002c0e8 | - | - |
| GetCommandLineW | 0x0002c0f0 | - | - |
| GetCPInfo | 0x0002c0f8 | - | - |
| GetOEMCP | 0x0002c100 | - | - |
| GetACP | 0x0002c108 | - | - |
| IsValidCodePage | 0x0002c110 | - | - |
| FindNextFileW | 0x0002c118 | - | T1083 |
| FindFirstFileExW | 0x0002c120 | - | - |
| FindClose | 0x0002c128 | - | - |
| HeapReAlloc | 0x0002c130 | - | - |
| LCMapStringW | 0x0002c138 | - | - |
| LoadLibraryExW | 0x0002c140 | - | - |
| VirtualProtect | 0x0002c148 | - | T1055 |
| GetFileType | 0x0002c150 | - | - |
| GetConsoleMode | 0x0002c158 | - | - |
| GetConsoleOutputCP | 0x0002c160 | - | - |
| FlushFileBuffers | 0x0002c168 | - | - |
| UnhandledExceptionFilter | 0x0002c170 | - | - |
| IsDebuggerPresent | 0x0002c178 | - | T1622 |
| RtlVirtualUnwind | 0x0002c180 | yes | - |
| RtlCaptureContext | 0x0002c188 | yes | - |
| HeapAlloc | 0x0002c190 | - | - |
| HeapFree | 0x0002c198 | - | - |
| IsProcessorFeaturePresent | 0x0002c1a0 | - | - |
| WriteFile | 0x0002c1a8 | - | - |
| GetStdHandle | 0x0002c1b0 | - | - |
| GetModuleFileNameW | 0x0002c1b8 | - | - |
| TerminateProcess | 0x0002c1c0 | - | - |
| ExitProcess | 0x0002c1c8 | - | - |
| GetCurrentProcess | 0x0002c1d0 | - | - |
| GetModuleHandleExW | 0x0002c1d8 | - | - |
| FreeLibraryAndExitThread | 0x0002c1e0 | - | - |
| ExitThread | 0x0002c1e8 | - | - |
| CreateThread | 0x0002c1f0 | - | - |
| RtlPcToFileHeader | 0x0002c1f8 | yes | - |
| RaiseException | 0x0002c200 | - | - |
| EncodePointer | 0x0002c208 | - | - |
| GetCommandLineA | 0x0002c210 | - | - |
| CloseHandle | 0x0002c218 | - | - |
| InitializeCriticalSection | 0x0002c220 | - | - |
| EnterCriticalSection | 0x0002c228 | - | - |
| LeaveCriticalSection | 0x0002c230 | - | - |
| DeleteCriticalSection | 0x0002c238 | - | - |
| WaitForSingleObject | 0x0002c240 | - | - |
| Sleep | 0x0002c248 | - | - |
| GetSystemTimes | 0x0002c250 | - | - |
| GetSystemInfo | 0x0002c258 | - | - |
| GetLocalTime | 0x0002c260 | - | - |
| GetTickCount | 0x0002c268 | - | T1497 |
| FreeLibrary | 0x0002c270 | - | - |
| GetProcAddress | 0x0002c278 | - | T1129 |
| LoadLibraryExA | 0x0002c280 | - | - |
| ReleaseSRWLockExclusive | 0x0002c288 | - | - |
| AcquireSRWLockExclusive | 0x0002c290 | - | - |
| WakeAllConditionVariable | 0x0002c298 | - | - |
| SleepConditionVariableSRW | 0x0002c2a0 | - | - |
| SetUnhandledExceptionFilter | 0x0002c2a8 | - | - |
| GetStartupInfoW | 0x0002c2b0 | - | - |
| GetModuleHandleW | 0x0002c2b8 | - | - |
| QueryPerformanceCounter | 0x0002c2c0 | - | T1497 |
| GetCurrentProcessId | 0x0002c2c8 | - | - |
| GetCurrentThreadId | 0x0002c2d0 | - | - |
| GetSystemTimeAsFileTime | 0x0002c2d8 | - | - |
| InitializeSListHead | 0x0002c2e0 | - | - |
| RtlLookupFunctionEntry | 0x0002c2e8 | yes | - |
| RtlUnwindEx | 0x0002c2f0 | yes | - |
| GetLastError | 0x0002c2f8 | - | - |
| SetLastError | 0x0002c300 | - | - |
| FlsAlloc | 0x0002c308 | - | - |
| FlsGetValue | 0x0002c310 | - | - |
| FlsSetValue | 0x0002c318 | - | - |
| FlsFree | 0x0002c320 | - | - |
| InitializeCriticalSectionEx | 0x0002c328 | - | - |
Binary metadata
what the headers declare about this build| Resource langs | - |
|---|---|
| Debug info | yes |
| TLS callbacks | yes |
Code signing
UnsignedThis binary carries no Authenticode signature. Unsigned executables are a weak suspicious signal - most legitimate vendor software is signed.
Resources
Everything the binary carries inside it: icons, bitmaps, cursors, dialogs, string tables, the manifest and the version block. Select an entry to preview it and take a copy.
Resources
none embeddedThis binary carries no resources
The PE has no resource directory: no icons, bitmaps, cursors, dialogs, string tables, manifest or version block are embedded in it. Nothing was skipped - there is nothing of this kind in the file.
Threat classification
Signature family candidates| Family | Agreeing rules | Matched rules | Disposition |
|---|---|---|---|
| Tiger RAT | 1 | TigerRAT_pe_yaraify | Not a classification: one rule cannot establish a family, so this named nothing and scored nothing. |
Capability detection
35 capabilities| Capability | Namespace |
|---|---|
| create process on Windows | host-interaction/process/create |
| calculate modulo 256 via x86 assembly | - |
| link function at runtime on Windows | linking/runtime-linking |
| create or open file | - |
| delay execution | - |
| encode data using XOR | data-manipulation/encoding/xor |
| hash data using sha256 via x86 extensions | data-manipulation/hashing/sha256 |
| connect socket | communication/socket |
| create thread | host-interaction/thread/create |
| change memory protection | - |
| PEB access | - |
| contain loop | - |
| get graphical window text | host-interaction/gui/window/get-text |
| schedule task via at | persistence/scheduled-tasks |
| send data on socket | communication/socket/send |
| send data | communication |
| hash data using SHA256 | data-manipulation/hashing/sha256 |
| check for time delay via GetTickCount | anti-analysis/anti-debugging/debugger-detection |
| enumerate PE sections | load-code/pe |
| receive data on socket | communication/socket/receive |
| receive data | communication |
| get socket status | communication/socket |
| set socket configuration | communication/socket |
| resolve DNS | communication/dns |
| get system information on Windows | host-interaction/os/info |
| initialize Winsock library | communication/socket |
| parse PE header | load-code/pe |
| terminate process | host-interaction/process/terminate |
| write file on Windows | host-interaction/file-system/write |
| enumerate files on Windows | host-interaction/file-system/files/list |
| query environment variable | host-interaction/environment-variable |
| read file on Windows | host-interaction/file-system/read |
| get file size | host-interaction/file-system/meta |
| clear file content | host-interaction/file-system/write |
| reference analysis tools strings | anti-analysis |
Signature matches
1 finding · 4 file properties · 0 scored| Rule | What it matched | Corpus | Weight |
|---|---|---|---|
|
TigerRAT_pe_yaraify
rule dated 2026-08-21
|
YARAify-tightened byte rule from 9 sample(s) -- VERIFY hits
1 of 1 string matched
$c0
\x0f\xb6\x08B\x0f\xb6\x14\x00+\xcau\x07H\xff\xc0\x85\xd2u\xed
at 0xd71b
|
Tier 1 - curated family set
licence-gated and benign-tested; may name a malware family
|
SCORED 0
Scored 0: the rule declares no category. No branch of the score model reads it.
Names Tiger RAT, but one rule cannot establish a family: two independent rules must agree, so this named nothing.
|
These say what the file IS or holds - bitness, subsystem, an overlay, an embedded macro stream, which compiler built it. Ordinary files match several, and none of them carry weight in the score.
None of the rules above moved the score. The score model reads four rule categories - anti-vm, anti-debug, dropper and packer - and a rule outside them can match, and be worth reading, without being evidence the verdict is built on.
Extracted strings
showing 200 of 573- !This program cannot be run in DOS mode.
- .text
- `.rdata
- @.data
- .pdata
- @.nv_fatbh
- @.fptable
- .reloc
- @USVWATAUAVAWH
- t$ UWATAUAVH
- t$ UWATAVAWH
- L$DHi
- xqt.I
- ntel
- ineI
- Genu
- G0Hch
- G0Lch
- p AWH
- stZE
- stXE
- stYE
- VWATAVAWH
- UWATAVAWH
- @USWH
- @USVWATAVAWH
- USVWATAUAVAWH
- WATAVH
- xtCA
- t\<jtLA
- x ATAVAWH
- VWATAVAW
- @USVWATAUAVH
- l$ VWATAVAWH
- ATAVAWH
- USVWATAVAWH
- ATAUAVAWH
- dybE3
- // SHA256 constants
- inline uint bswap32_cl(uint x) {
- __kernel void sha256d_opencl_kernel(
- __global const uint* midstate,
- __global const uint* tail,
- uint nonce_base,
- __global uint* results
- uint nonce = nonce_base + get_global_id(0);
- // Load midstate
- // Second block: tail + nonce + padding
- // Second SHA256 on the 32-byte result
- uint final_h = 0x5be0cd19 + h;
- uint le_h = bswap32_cl(final_h);
- // Check if hash meets minimum difficulty (last 4 bytes zero)
- uint idx = atomic_add(&results[0], 1);
- bestshare.txt
- %lf %7s
- %.2f %s
- solopool_config.txt
- address=%s
- password=%s
- address=
- password=
- %s: %u%%
- solopool_miner.log
- -cl-mad-enable -cl-fast-relaxed-math
- OpenCL build error: %s
- sha256d_opencl_kernel
- CUDA GPU %d: %s (%d SMs)
- NVIDIA
- OpenCL GPU %d: %s
- GPU: %d CUDA + %d OpenCL devices
- GPU: %d CUDA device(s)
- GPU: %d OpenCL device(s)
- No GPU devices found
- Connected to %s:%d
- mining.submit
- mining.suggest_difficulty
- TX: %s
- {"id":99,"method":"mining.suggest_difficulty","params":[%d]}
- >>> Suggested new difficulty: %d (was pool diff: %d)
- %s%s%s%s
- 0000000000000000000000000000000000000000000000000000000000000000
- %s%s%s%s%s%s
- "params"
- true
- Ready to submit shares
- [CLEAN]
- New job: %s diff=%.0f %s
- Pool difficulty: %.0f
- {"id":1,"method":"mining.subscribe","params":["SoloPoolMiner/44.3-GUI"]}
- Subscribed: extranonce1=%s, size=%d
- {"id":2,"method":"mining.authorize","params":["%s","%s"]}
- {"id":3,"method":"mining.suggest_difficulty","params":[%d]}
- Suggested initial difficulty: %d
- mining.notify
- mining.set_difficulty
- Authorized OK
- "result":true
- Share ACCEPTED [%u/%u]
- "result":false
- reject
- Share REJECTED [%u/%u]
- {"id":%d,"method":"mining.submit","params":["%s","%s","%s","%s","%s"]}
- [%s] Share diff=%.1f (pool=%.0f)
- Connection lost, reconnecting...
- Error
- Please enter a valid Bitcoin address
- stratum.solopool.com
- SoloPool Miner v1.0.4 - GUI Edition
- stratum.solopool.com:3333
- Pool: %s
- Worker: %s
- CPU: %d threads @ %d%% power | GPU: %d device(s) @ %d%% power
- Stopping miner...
- Miner stopped
- CPU: %u/%u | GPU: %u/%u | Total: %u/%u (%.1f%%) | SPM: %.1f
- Best: %.1f / %.1f | Uptime: %02d:%02d:%02d | Diff: %.0f | Suggested: %d
- Consolas
- SoloPool.Com Miner v1.0.4
- STATIC
- Pool: stratum.solopool.com:3333
- Worker:
- EDIT
- Password:
- Enable CPU Mining
- BUTTON
- Power
- msctls_trackbar32
- %d%%
- Enable GPU Mining
- Generate Coins
- Stop Mining
- View My Stats on SoloPool
- CPU Red Zone
- CPU RED ZONE ACTIVATED!
- CPU is now running above 80% power.
- WARNING:
- - Increased heat and power consumption
- - Higher CPU temperatures
- - May cause system instability
- Monitor your temps!
- GPU Red Zone
- GPU RED ZONE ACTIVATED!
- GPU is now running above 80% power.
- - Higher GPU temperatures
- - Potential thermal throttling
- https://www.solopool.com/user.html?network=mainnet&address=%s
- open
- Info
- Please enter a valid Bitcoin address first
- SoloPool Miner
- Mining is in progress. Stop and exit?
- SoloPoolMinerGUIClass
- SoloPool.Com Miner v1.0.4 - CUDA + CPU Hybrid
- Failed to create window
- SoloPool Miner v1.0.4 GUI ready
- SHA256-NI
- Software
- CPU: %d cores | SHA: %s
- Best share ever: %.2f (%s)
- Enter your BTCADDR.WORKERNAME and click 'Generate Coins' to start!
- _Z19sha256d_cuda_kernelPKjS0_jPj
- o.ho,
- nvcuda.dll
- cuGetProcAddress_v2
- cuGetExportTable
- nvcudart_hybrid64.dll
- __cdecl
- __stdcall
- __thiscall
- __fastcall
- __vectorcall
- __preserve_none
- __clrcall
- __eabi
- __restrict
- __unaligned
- restrict(
- delete
- operator
- `vftable'
- `vbtable'
- `vcall'
- `typeof'
- `local static guard'
- `string'
- `vbase destructor'
- `vector deleting destructor'
- `default constructor closure'
- `scalar deleting destructor'
- `vector constructor iterator'
- `vector destructor iterator'
- `vector vbase constructor iterator'
- `virtual displacement map'
- `eh vector constructor iterator'
- `eh vector destructor iterator'
- `eh vector vbase constructor iterator'
- `copy constructor closure'
- `udt returning'
- `RTTI
- `local vftable'
No strings match this filter.
Stack and decoded strings were not recovered: it did not finish within the time allowed. Only literal strings present in the file are listed above.
Disassembly
entry point · x64 · 60 insns (listing capped)Nothing in this view
This sample produced no results for this part of the static analysis.
Screen recording
41 frames · screen recording · 134sBehavior summary
ran 134s5 process(es) observed
Evasion / anti-analysis checks
8 checksStatically visible checks (RDTSC/CPUID/red-pill instructions, anti-debug APIs) plus runtime evasion signals. Instruction-level interception at runtime requires hypervisor introspection (VMI).
No WMI attributed to the sample. The WMI-Activity trace was running and recorded 824 operations on the machine during the run; none of them came from the sample's process tree.
Command lines, unwrapped
2 read2 captured texts were read and unwrapped locally. No address was recovered from any of them, and none of them was hiding its own contents behind an encoding or a format string. This is a result, not a gap.
Network activity
The network section is a paid-plan layer: the DNS the sample resolved, the connections it opened, the TLS it negotiated, and the rule engine's reading of the capture.
This run was captured, and what it captured is on a paid plan rather than absent. An internet-connected detonation is the same plan, so a paid run also shows what the sample reached rather than only what it tried.
Process tree
What ran during the detonation, and what each process did. Select a node to see the activity attributed to it.
SoloPoolMiner.exe
5 processesAttributed activity
Nothing in this run was attributed to this process. That is not the same as "it did nothing" - it means no captured operation carried its pid.
Nothing in this run was attributed to this process. That is not the same as "it did nothing" - it means no captured operation carried its pid.
Nothing in this run was attributed to this process. That is not the same as "it did nothing" - it means no captured operation carried its pid.
Nothing in this run was attributed to this process. That is not the same as "it did nothing" - it means no captured operation carried its pid.
Nothing in this run was attributed to this process. That is not the same as "it did nothing" - it means no captured operation carried its pid.
Persistence mechanisms
cleanNo persistence established
None of the 90 auto-start methods below were established during this run.
Detection coverage
0 / 90Every auto-start method checked on this sample, grouped by family. A method with no result is reported clean, and one the sample only names in its own strings reads "named" rather than "detected".
- Active Setup Installed Component T1547.014 clean
- Explorer Delay-Load Object T1547.001 clean
- Explorer Run Key T1547.001 clean
- Explorer SharedTaskScheduler T1547.001 clean
- Group Policy Extension DLL T1547.004 clean
- Group Policy Run Key T1547.001 clean
- Logon Script T1037.001 clean
- RDP WDS Startup Program T1547.001 clean
- Registry Run Key T1547.001 clean
- Registry RunEx Key T1547.001 clean
- Registry RunOnce Key T1547.001 clean
- Registry RunOnceEx Key T1547.001 clean
- Registry RunServices Key T1547.001 clean
- Startup Folder Item T1547.001 clean
- Startup Folder Redirection T1547.001 clean
- Terminal Services Initial Program T1547.001 clean
- Winlogon GINA DLL T1547.004 clean
- Winlogon MPNotify Value T1547.004 clean
- Winlogon Notify Package T1547.004 clean
- Winlogon Shell Value T1547.004 clean
- Winlogon Taskman Value T1547.004 clean
- Winlogon Userinit Value T1547.004 clean
- BITS Job T1197 clean
- Print Monitor DLL T1547.010 clean
- Print Processor DLL T1547.012 clean
- Scheduled Task T1053.005 clean
- Scheduled Task Registry Implant T1053.005 clean
- Service Control Manager Security Descriptor T1574.011 clean
- Service DLL Hijack T1543.003 clean
- Time Provider DLL T1547.003 clean
- Windows Service Creation T1543.003 clean
- .NET Managed Debugger T1546.012 clean
- Accessibility Tool Hijack T1546.008 clean
- AeDebug Postmortem Debugger T1546.012 clean
- App Paths Hijack T1546.012 clean
- Application Shim Database T1546.011 clean
- Boot Verification Program T1547.002 clean
- Command Processor AutoRun T1546.011 clean
- Explorer Load Value T1547.001 clean
- Explorer MyComputer Tool Hijack T1546.001 clean
- Registry Image File Execution Options T1546.012 clean
- Screensaver Hijack T1546.002 clean
- Setup ErrorHandler Script T1546 clean
- Shell Open Command Hijack T1546.001 clean
- SilentProcessExit Monitor T1546.012 clean
- Telemetry Controller Command T1546.015 clean
- WER ReflectDebugger T1546.012 clean
- Windows Error Reporting Debugger T1546.012 clean
- .NET CLR Profiler DLL T1574.012 clean
- .NET Startup Hook DLL T1574 clean
- AppCert DLLs T1546.009 clean
- AppInit DLLs T1546.010 clean
- AutodialDLL Winsock Injection T1546.006 clean
- DLL Search-Order Hijack T1574.001 T1574.002 clean
- DNS Server Plugin DLL T1574.001 clean
- HTML Help Helper DLL T1546 clean
- KnownDLLs Manipulation T1574.001 clean
- Natural Language Platform DLL Override T1546 clean
- Netsh Helper DLL T1546.007 clean
- Winsock Layered Service Provider T1546.006 clean
- Browser Extension T1176 clean
- Browser Helper Object T1176 clean
- COM Server Hijack T1546.015 clean
- HTML Help COM Object Hijack T1546.015 clean
- Shell Context Menu Handler T1546.001 clean
- Shell Extension Handler T1546.001 clean
- Account RID Hijack T1098 clean
- AMSI Provider T1562.001 clean
- Credential Provider T1547.014 clean
- DSRM Admin Logon Backdoor T1556 clean
- Hidden Local Account T1136.001 clean
- LSA Authentication Package T1547.002 clean
- LSA Extension DLL T1547.005 clean
- LSA Notification Package T1547.005 clean
- LSA Security Package T1547.005 clean
- Network Provider DLL T1556.008 clean
- Security Support Provider T1547.005 clean
- Netsh Port Proxy T1090.001 clean
- Office Add-in T1137.006 clean
- Office Executable Sideload T1574.002 clean
- Office Startup Template T1137.001 clean
- Office Test Key T1137.002 clean
- Power Automate Flow T1546 clean
- PowerShell Profile T1546.013 clean
- Windows Terminal Startup Action T1546 clean
- WMI Event Subscription T1546.003 clean
- BootExecute Native Image T1547.002 clean
- PlatformExecute Native Image T1547.002 clean
- SetupExecute Native Image T1547.002 clean
- UEFI / Bootkit Artifact T1542.003 T1542.001 clean
File activity summary
Dropped payload analysis
none keptThe sample ran and none of what it wrote was a payload this run kept and examined. That is a measured absence rather than an unasked question.
File & registry ops
0 file · 0 registry · sample scope
| Operation | Target | Process |
|---|
No file or registry operations captured.
No operations match your filter.
External reputation was not produced for this scan. Threat intelligence enrichment is a paid-plan layer: every extracted indicator - hashes, addresses, hostnames - is checked against the external reputation services. Our own ingested feeds ran on this scan and every result below is theirs. Adding the paid layer adds an external reputation verdict on each indicator, so VirusTotal, MalwareBazaar and filescan.io are listed below as not checked. See plans.
File reputation
4 clear · 3 not checked| Source | Checks | Result | Detail | Feed |
|---|---|---|---|---|
| MalwareBazaar hash feed | File hash | clean | not in feed | 2,745 records 40 minutes ago |
| MalwareBazaar ransomware feed | File hash | clean | not in feed | 3,348 records 5 hours ago |
| ThreatFox hash IOCs | File hash | clean | not in feed | 1,158 records 41 minutes ago |
| URLhaus payload hashes | File hash | clean | not in feed | 1,642 records 40 minutes ago |
| filescan.io | File hash | not checked | no hash lookup ran for this scan | live lookup |
| MalwareBazaar | File hash | not checked | no hash lookup ran for this scan | live lookup |
| VirusTotal | File hash | not checked | no hash lookup ran for this scan | live lookup |
Hash lookups only - the sample itself is never uploaded to any third party.
Network indicators
7 clear · 1 could not answer| Source | Checks | Result | Detail | Feed |
|---|---|---|---|---|
| URLhaus | IP / domain / URL | feed unavailable | 1 observed indicator, none listed | no records ingested |
| blocklist.de | IP / domain / URL | clean | 1 observed indicator, none listed | 27.6k records 40 minutes ago |
| CINS Army | IP / domain / URL | clean | 1 observed indicator, none listed | 15k records 41 minutes ago |
| Emerging Threats | IP / domain / URL | clean | 1 observed indicator, none listed | 482 records 41 minutes ago |
| Feodo Tracker | IP / domain / URL | clean | 1 observed indicator, none listed | 5 records 41 minutes ago |
| IPsum | IP / domain / URL | clean | 1 observed indicator, none listed | 19.7k records 41 minutes ago |
| Phishing.Database | IP / domain / URL | clean | 1 observed indicator, none listed | 391.5k records 0 minutes ago |
| ThreatFox | IP / domain / URL | clean | 1 observed indicator, none listed | 1,158 records 41 minutes ago |
TLS fingerprints
nothing of this kind to check| Source | Checks | Result | Detail | Feed |
|---|---|---|---|---|
| JA3 / JA4 fingerprint blocklists | JA3 / JA4 | not checked | no TLS client fingerprint observed | 97 records 12 hours ago |
| SSL blocklist | Server certificate | not checked | no server certificate fingerprint is extracted to check | live lookup |
Detection rules
1 of 2 listed| Source | Checks | Result | Detail | Feed |
|---|---|---|---|---|
| Signature rules | Sample content | 1 match | TigerRAT_pe_yaraify | 110 records 41 minutes ago |
| Sigma rules | Behavior log | clean | - | 2,275 records 7 hours ago |
Tooling catalogs
4 clear| Source | Checks | Result | Detail | Feed |
|---|---|---|---|---|
| LOLBAS | Process image paths | clean | 5 process image paths, none masqueraded | 245 records 41 minutes ago |
| LOLBootloaders | File hash | clean | not a known vulnerable bootloader | 520 records 40 minutes ago |
| LOLDrivers | File hash | clean | not a known vulnerable driver | 2,333 records 41 minutes ago |
| LOLRMM | Names and domains | clean | 6 name/domain indicators checked, no remote-management tooling | 360 records 40 minutes ago |
AI analysis
The AI layer is a paid-plan feature. It reads what the other layers produced - the behaviour summary, the call sequence, the indicator list - and writes the narrative and the kill-chain walkthrough.
Nothing is being withheld. This layer did not run for this scan, so there is no result stored behind the lock.
File indicators
3| Severity | Type | Indicator | Description |
|---|---|---|---|
| suspicious | sample_sha256 | 7670bcd0ba77334cf0b1e46a0ab6b177949473d6f5d837fc940f2cb319a7ecfb | Submitted sample (SHA256) |
| suspicious | sample_md5 | 359e68af2e5fc2b3a044556e8c2c565e | Submitted sample (MD5) |
| suspicious | imphash | ec52d9411fe9e76a6d4996f2ef1afe57 | Import table hash (imphash) |
Sigma detections
0 matches of 2275 rulesThe Sigma corpus was evaluated against this run's processes, registry, file, network, DNS and script activity. Nothing matched.
Generated rules
YARA: auto_file_2582_yara
Auto-generatedrule auto_file_2582_yara
{
meta:
description = "Auto-generated from scan 2582"
author = "sandbox auto-generator"
imphash = "ec52d9411fe9e76a6d4996f2ef1afe57"
anchors = "5 independent regions"
strings:
$s0 = "{\"id\":1,\"method\":\"mining.subscribe\",\"params\":[\"SoloPoolMiner/44.3-GUI\"]}" ascii fullword
$s1 = "Build cuda_13.1.r13.1/compiler.36836380_0" ascii fullword
$s2 = "0000000000000000000000000000000000000000000000000000000000000000" ascii fullword
$s3 = ".rel.nv.constant0._Z19sha256d_cuda_kernelPKjS0_jPj" ascii fullword
$s4 = "SoloPool.Com Miner v1.0.4 - CUDA + CPU Hybrid" ascii fullword
condition:
uint16(0) == 0x5a4d and filesize < 1691648 and all of them
}Extracted files
What came out of the sample: unpacked payloads, carved objects and captured memory. Each one is stored by content hash, so the same object extracted twice is the same row.
No extracted files
Nothing was unpacked or carved out of this sample. Packed samples, documents with embedded objects and installers are the ones that usually produce artifacts here.
Export & download
/s/2582Structured exports for your SIEM/TIP - ATT&CK Navigator layer, STIX 2.1 bundle, MISP event and a defanged IOC list - are free on every report. The packet capture follows this scan's plan, because a capture is the rawest network output this platform produces.
AI analysis report
An enterprise report with an AI-written executive summary, threat assessment, kill chain, and recommendations, plus the derived evidence (verdict, MITRE ATT&CK, network, file modifications, dropped files, IOCs) and screenshots. The AI narrative is built from derived analysis data only, so the raw sample never leaves the host (no-upload and AI-boundary preserved).
Headers
Body
Headers
Body
You are about to download the raw, live sample. It is real, potentially destructive malware and can harm your machine if opened or run. Only handle it inside an isolated analysis environment.
Delivered as a ZIP encrypted with the password infected so the bytes are never handled unprotected.
Report this analysis
Analysis reports are produced automatically from files, addresses and text submitted by visitors. If this one publishes your material, identifies you, or should not be public for any other reason, tell us why and an administrator will review it.
Public analyses of this file
1 run| Submitted | Environment | Verdict | Score |
|---|---|---|---|
| 2026-09-30 01:26 Shown below | Windows 10 22H2 | Suspicious | 35/100 |